summaryrefslogtreecommitdiffstats
path: root/lib/kformula/rootelement.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kformula/rootelement.h')
-rw-r--r--lib/kformula/rootelement.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/kformula/rootelement.h b/lib/kformula/rootelement.h
index b836228e..4908a643 100644
--- a/lib/kformula/rootelement.h
+++ b/lib/kformula/rootelement.h
@@ -62,11 +62,11 @@ public:
* is allowed to set the cursor.
*/
virtual BasicElement* goToPos( FormulaCursor*, bool& handled,
- const LuPixelPoint& point, const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& point, const LuPixelPoint& parentOrigin );
/**
* Calculates our width and height and
- * our tqchildren's tqparentPosition.
+ * our tqchildren's parentPosition.
*/
virtual void calcSizes( const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
@@ -75,15 +75,15 @@ public:
/**
* Draws the whole element including its tqchildren.
* The `tqparentOrigin' is the point this element's tqparent starts.
* We can use our tqparentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,
const ContextStyle& cstyle,
ContextStyle::TextStyle tstyle,
ContextStyle::IndexStyle istyle,
StyleAttributes& style,
- const LuPixelPoint& tqparentOrigin );
+ const LuPixelPoint& parentOrigin );
/**
* Dispatch this FontCommand to all our TextElement tqchildren.
@@ -75,15 +75,15 @@ public:
/**
* Draws the whole element including its tqchildren.
- * The `tqparentOrigin' is the point this element's tqparent starts.
- * We can use our tqparentPosition to get our own origin then.
+ * The `parentOrigin' is the point this element's tqparent starts.
+ * We can use our parentPosition to get our own origin then.
*/
virtual void draw( TQPainter& painter, const LuPixelRect& r,